==> gmusicapi_scripts-0.3.0.zip: gmusicapi_scripts-0.3.0/README.md <==
gmusicapi-scripts
=================

A collection of scripts for [gmusicapi](https://github.com/simon-weber/Unofficial-Google-Music-API) using [gmusicapi-wrapper](https://github.com/thebigmunch/gmusicapi-wrapper).

## Requirements

* Python 3.4+
* [gmusicapi](https://github.com/simon-weber/Unofficial-Google-Music-API)
* [gmusicapi-wrapper](https://github.com/thebigmunch/gmusicapi-wrapper)
* [mutagen](https://bitbucket.org/lazka/mutagen)
* [docopt](https://github.com/docopt/docopt)
* ffmpeg or avconv for uploading non-mp3 files (See [here](http://unofficial-google-music-api.readthedocs.org/en/latest/usage.html#usage))

## Installation

* Stable release

		pip install gmusicapi-scripts
		pip install git+https://github.com/thebigmunch/gmusicapi-scripts

* Development release

		pip install git+https://github.com/thebigmunch/gmusicapi-scripts@devel

## Usage

See the [USAGE.md](https://github.com/thebigmunch/gmusicapi-scripts/blob/master/USAGE.md) file or the online [Wiki](https://github.com/thebigmunch/gmusicapi-scripts/wiki)

## Contributing

See the [CONTRIBUTING.md](https://github.com/thebigmunch/gmusicapi-scripts/blob/master/CONTRIBUTING.md) file

## FAQ

##### Is it possible to add support for downloading All Access songs?

Yes.

##### Would you add support for downloading All Access songs?

Almost certainly never. All Access songs are obviously not intended for download. Your All Access subscription allows you to stream these songs as long as you subscribe. Circumventing this restriction would only bring unwanted attention, criticism, and repercussions to gmusicapi.

## Contact

You can contact the author in ``#gmusicapi`` on ``irc.freenode.net`` or by [e-mail](mailto:mail@thebigmunch.me)

## Donate

Donations, as any compliment, are appreciated but not expected.

[![Bitcoin](http://img.shields.io/badge/bitcoin-donate-green.svg?style=flat-square)](https://coinbase.com/thebigmunch) [![Flattr](http://img.shields.io/badge/flattr-donate-green.svg?style=flat-square)](https://flattr.com/thing/2419308) [![PayPal](http://img.shields.io/badge/paypal-donate-green.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=DHDVLSYW8V8N4&lc=US&item_name=thebigmunch&currency_code=USD)  
[![Coinbase](http://img.shields.io/badge/coinbase-referral-orange.svg?style=flat-square)](https://coinbase.com/?r=52502f01e0fdd4d3ef000253&utm_campaign=user-referral&src=referral-link) [![Digital Ocean](http://img.shields.io/badge/digital ocean-referral-orange.svg?style=flat-square)](https://www.digitalocean.com/?refcode=3823208a0597) [![Namecheap](http://img.shields.io/badge/namecheap-referral-orange.svg?style=flat-square)](http://www.namecheap.com/?aff=67208)

-----

Copyright (c) 2016 [thebigmunch](mailto:mail@thebigmunch.me). Licensed under the MIT License. See [LICENSE](LICENSE).

==> gmusicapi_scripts-0.4.0.zip: gmusicapi_scripts-0.4.0/README.md <==
gmusicapi-scripts
=================

A collection of scripts for [gmusicapi](https://github.com/simon-weber/gmusicapi) using [gmusicapi-wrapper](https://github.com/thebigmunch/gmusicapi-wrapper).


## Documentation

Documentation is available online at <https://thebigmunch.github.io/gmusicapi-scripts>. There you can find [install instructions](https://thebigmunch.github.io/gmusicapi-scripts/install/), [usage instructions](https://thebigmunch.github.io/gmusicapi-scripts/usage/), and [contributing guidelines](https://thebigmunch.github.io/gmusicapi-scripts/contributing/).


## Contact

You can contact the author in ``#gmusicapi`` on ``irc.freenode.net`` or by [e-mail](mailto:mail@thebigmunch.me)


## Donate

Donations, as any compliment, are appreciated but not expected. I include these because people have shown interest.

[![Bitcoin](http://img.shields.io/badge/bitcoin-donate-green.svg?style=flat-square)](https://coinbase.com/thebigmunch) [![Flattr](http://img.shields.io/badge/flattr-donate-green.svg?style=flat-square)](https://flattr.com/thing/2419308) [![PayPal](http://img.shields.io/badge/paypal-donate-green.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=DHDVLSYW8V8N4&lc=US&item_name=thebigmunch&currency_code=USD)
[![Coinbase](http://img.shields.io/badge/coinbase-referral-orange.svg?style=flat-square)](https://coinbase.com/?r=52502f01e0fdd4d3ef000253&utm_campaign=user-referral&src=referral-link) [![Digital Ocean](http://img.shields.io/badge/digital ocean-referral-orange.svg?style=flat-square)](https://www.digitalocean.com/?refcode=3823208a0597) [![Namecheap](http://img.shields.io/badge/namecheap-referral-orange.svg?style=flat-square)](http://www.namecheap.com/?aff=67208)

-----

Copyright (c) 2016 [thebigmunch](mailto:mail@thebigmunch.me). Licensed under the MIT License. See [LICENSE](LICENSE).
